@@ -1,8 +1,8 @@
 mfdmedian <- function(x,
-                    type = "hdepth",
-                    crossDepthsX = NULL,
-                    depthOptions = NULL,
-                    centerOption = "maxdepth") {
+                      type = "hdepth",
+                      crossDepthsX = NULL,
+                      depthOptions = NULL,
+                      centerOption = "maxdepth") {
 
   ######
   # Check input.
@@ -10,7 +10,7 @@ mfdmedian <- function(x,
     stop("Input argument x is required.")
   }
 
-  #Check x
+  # Check x
   if (!is.array(x)) {
     stop("x must be a three dimensional array.")
   }
@@ -24,17 +24,17 @@ mfdmedian <- function(x,
   n1 <- dim(x)[2]
   p1 <- dim(x)[3]
 
-  #Check type
+  # Check type
   Indtype <- match(type, c("hdepth", "projdepth",
-                           "sprojdepth", "dprojdepth", "simplicial"))[1]
+                           "sprojdepth", "dprojdepth", "sdepth"))[1]
   if (is.na(Indtype)) {
-    stop("type should be one of hdepth, projdepth , sprojdepth, dprojdepth or simplicial.")
+    stop("type should be one of hdepth, projdepth, sprojdepth, dprojdepth or sdepth")
   }
   if (Indtype == 5 & p1 > 2) {
-    stop("Simplicial depth only implemented for p<=2.")
+    stop("Simplicial depth is only implemented for p<=2.")
   }
 
-  #Check the crossDepths
+  # Check the crossDepths
   if (!is.null(crossDepthsX)) {
     if (!is.matrix(crossDepthsX)) {
       stop("crossDepthsX should be a matrix")
@@ -57,7 +57,7 @@ mfdmedian <- function(x,
     }
   }
 
-  #check depthOptions
+  # check depthOptions
   if (is.null(depthOptions)) {
     depthOptions <- list()
   }
@@ -65,16 +65,15 @@ mfdmedian <- function(x,
     stop("depthOptions must be a list")
   }
 
-  #check centerOption
-  indCenter <- match(centerOption, c("maxdepth", "gravity", "Huber"))[1]
+  # check centerOption
+  indCenter <- match(centerOption, c("maxdepth", "Huber"))[1]
   if (is.na(indCenter)) {
-    stop("centerOption should be one of maxdepth, gravity or Huber.")
+    stop("centerOption should be one of maxdepth or Huber.")
   }
-  if (indCenter == 3 && (Indtype == 3 || Indtype == 4)) {
-    stop("Huber estimate not available for sprojmedian and dprojmedian.")
+  if (indCenter == 2 && Indtype != 2) {
+    stop("Huber weights are only available for projection median.")
   }
 
-
   MFDmedian <- matrix(NaN, nrow = t1, ncol = p1)
 
   warningFlagFit <- 0
@@ -84,15 +83,15 @@ mfdmedian <- function(x,
   for (j in 1:t1) {
     exactfit <- 0
 
-    #R has standard dimension dropping, we need to be carefull
+    # R has standard dimension dropping, we need to be careful
     if (p1 == 1)  {
-      xTimePoint <- matrix(x[j,,1])
+      xTimePoint <- matrix(x[j, , 1])
     }
-    else{
-      xTimePoint <- x[j,,,drop = TRUE]
+    else {
+      xTimePoint <- x[j, , , drop = TRUE]
     }
 
-    #Find cross-sectional depth
+    # Find cross-sectional depth
     if (type == "hdepth") {
       temp <- try(do.call(hdepthmedian, c(list(x = xTimePoint), depthOptions)),
                   silent = TRUE)
@@ -100,74 +99,70 @@ mfdmedian <- function(x,
         temp <- list()
       }
       if (!is.null(temp$median)) {
-        MFDmedian[j,] <- temp$median
+        MFDmedian[j, ] <- temp$median
       }
-      else{
+      else {
         exactfit <- 1
       }
     }
     else if (type == "projdepth") {
       if (is.null(crossDepthsX)) {
         temp <- projmedian(x = xTimePoint, options = depthOptions)
-      } else{
+      } else {
         temp <- projmedian(x = xTimePoint,
-                           projection.depths = crossDepthsX[,j])
+                           projection.depths = crossDepthsX[, j])
       }
       if (!is.null(temp$max)) {
-        if (centerOption == 1) {
-          MFDmedian[j,] <- temp$max
+        if (indCenter == 1) {
+          MFDmedian[j, ] <- temp$max
         }
-        else if (centerOption == 2) {
-          MFDmedian[j,] <- temp$gravity
-        } else {
-          MFDmedian[j,] <- temp$Huber
+        else {
+          MFDmedian[j, ] <- temp$Huber
         }
       }
-      else{
+      else {
         exactfit <- 1
       }
     }
     else if (type == "sprojdepth") {
       if (is.null(crossDepthsX)) {
         temp <- sprojmedian(x = xTimePoint, options = depthOptions)
-      } else{
+      } else {
         temp <- sprojmedian(x = xTimePoint,
-                            sprojection.depths =  crossDepthsX[,j])
+                            sprojection.depths = crossDepthsX[, j])
       }
       if (!is.null(temp$max)) {
-        if (centerOption == 1) {
-          MFDmedian[j,] <- temp$max
+        if (indCenter == 1) {
+          MFDmedian[j, ] <- temp$max
         }
-        else MFDmedian[j,] <- temp$gravity
       }
-      else{
+      else {
         exactfit <- 1
       }
     }
     else if (type == "dprojdepth") {
       if (is.null(crossDepthsX)) {
         temp <- dprojmedian(x = xTimePoint, options = depthOptions)
-      } else{
+      } else {
         temp <- dprojmedian(x = xTimePoint,
                             dprojection.depths =  crossDepthsX[,j])
       }
       if (!is.null(temp$max)) {
-        if (centerOption == 1) {
-          MFDmedian[j,] <- temp$max
+        if (indCenter == 1) {
+          MFDmedian[j, ] <- temp$max
         }
-        else MFDmedian[j,] <- temp$gravity
       }
-      else{
+      else {
         exactfit <- 1
       }
-    }
-    else{
+    }    
+    else {
       temp <- sdepth(x = xTimePoint)
       if (!is.null(temp$depth)) {
         Ind <- which(temp$depth == max(temp$depth))
-        MFDmedian[j,] <- colMeans(matrix(xTimePoint[Ind,], ncol = p1))
+        MFDmedian[j, ] <- colMeans(matrix(xTimePoint[Ind, ], ncol = p1))
       }
-      else{
+      else {
         exactfit <- 1
       }
     }
@@ -184,11 +179,11 @@ mfdmedian <- function(x,
   class(Result) <- c("mrfDepth", "mfdmedian")
   
 
-  #Handle all warnings
+  # Handle all warnings
   if (warningFlagFit == 1) {
     warning(paste("Exact fits were detected for certain time points.",
                   "Their weights will be set to zero.",
-                  " Check the returned results", call. = FALSE)
+                  "Check the returned results", call. = FALSE)
             )
     Result$IndFlagExactFit <- warningIndFit
   }
